#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_ELEVEN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_ELEVEN_HPP_INCLUDED

#include <boost/simd/constant/include/constants/eleven.hpp>

#endif
